#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 trifecta
version:              2.1.4
visibility:           public
id:                   trifecta-2.1.4-7JTK1zuRFxH6X52mXBJ9HJ
key:                  trifecta-2.1.4-7JTK1zuRFxH6X52mXBJ9HJ
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  ba0e33f7693f26db892eb3ea466c1b53
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-trifecta
hs-libraries:         HStrifecta-2.1.4-7JTK1zuRFxH6X52mXBJ9HJ
depends:
    ansi-terminal-1.1-Hf6fFmjaIfCVZ3DoDW5HB array-0.5.6.0 base-4.18.2.1
    blaze-builder-0.4.4.1-9Evz8oerfDZ9EQvA8PZ07a
    blaze-html-0.9.2.0-IQpYWAMPsDd8u1EAzkbal7
    blaze-markup-0.8.3.0-8LKEXVAssOfaSB46gmUNg bytestring-0.11.5.3
    charset-0.3.12-JmNI92gX7KxLfT3TE8Y1Uv
    comonad-5.0.10-EXUe6qWqQMj9EujznH0ooo containers-0.6.7
    deepseq-1.4.8.1 fingertree-0.1.6.3-AjtEp1LLvbnIthSmL26CL9
    ghc-prim-0.10.0 hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    indexed-traversable-0.1.5-joXpPaCxYw3UYRlFaP36
    lens-5.3.5-7MUa280kiW5NfytVlUfpR mtl-2.3.1
    parsers-0.12.12-6PzuTVTFE7z3uuo6BM0nb2
    prettyprinter-1.7.2-JipenGj1ZXCGzFGneLGC87
    prettyprinter-ansi-terminal-1.1.4-1eYFKNqRJpCEJbcAlUbmrg
    profunctors-5.6.3-Dzx15pSWheZIsI1nl8d4qX
    reducers-3.12.5-8XDjgNtlNdhI909kSD6zf0 transformers-0.6.1.0
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

